==> anaplan_sdk-0.2.10.tar.gz: anaplan_sdk-0.2.10/docs/index.md <==
<p align="center" style="margin: 0 0 10px">
    <img width="200" height="200" src="img/anaplan-sdk.webp" alt='Python' style="border-radius: 15px">
</p>

<h1 align="center" style="font-size: 3rem; font-weight: 400; margin: -15px 0">
Anaplan SDK
</h1>

<p align="center" style="margin-top: 15px">
<a href="https://pepy.tech/project/anaplan-sdk">
<img align="center" src="https://static.pepy.tech/badge/anaplan-sdk/month" alt="Downloads Badge"/>
</a>
</p>

---

Anaplan SDK is an independent, unofficial project providing pythonic access to Anaplan. Anaplan SDK provides high-level
abstractions over the various Anaplan APIs, so you can focus on you requirements rather than spend time on
implementation details like authentication, error handling, chunking, compression and data formatting.

This Projects supports
the [Bulk APIs](https://help.anaplan.com/use-the-bulk-apis-93218e5e-00e5-406e-8361-09ab861889a7),
the [Transactional APIs](https://help.anaplan.com/use-the-transactional-apis-cc1c1e91-39fc-4272-a4b5-16bc91e9c313) and
the [ALM APsI](https://help.anaplan.com/application-lifecycle-management-api-2565cfa6-e0c2-4e24-884e-d0df957184d6),
the [Audit APIs](https://auditservice.docs.apiary.io/#),
providing both synchronous and asynchronous Clients.

---

Head over to the [Quick Start](quickstart.md) to get started with the basics.

If you find any issues or feel that this SDK is not adequately covering your use case,
please [open an issue](https://github.com/VinzenzKlass/anaplan-sdk/issues/new).

==> anaplan_sdk-0.3.1.tar.gz: anaplan_sdk-0.3.1/docs/index.md <==
<p align="center" style="margin: 0 0 10px">
    <img width="200" height="200" src="img/anaplan-sdk.webp" alt='Python' style="border-radius: 15px">
</p>

<h1 align="center" style="font-size: 3rem; font-weight: 400; margin: -15px 0">
Anaplan SDK
</h1>

<p align="center" style="margin-top: 15px">
<a href="https://pepy.tech/project/anaplan-sdk">
<img align="center" src="https://static.pepy.tech/badge/anaplan-sdk/month" alt="Downloads Badge"/>
</a>
</p>

---

Anaplan SDK is an independent, unofficial project providing pythonic access to Anaplan. Anaplan SDK provides high-level
abstractions over the various Anaplan APIs, so you can focus on you requirements rather than spend time on
implementation details like authentication, error handling, chunking, compression and data formatting.

This Projects supports
the [Bulk APIs](https://help.anaplan.com/use-the-bulk-apis-93218e5e-00e5-406e-8361-09ab861889a7),
the [Transactional APIs](https://help.anaplan.com/use-the-transactional-apis-cc1c1e91-39fc-4272-a4b5-16bc91e9c313) and
the [ALM APIs](https://help.anaplan.com/application-lifecycle-management-api-2565cfa6-e0c2-4e24-884e-d0df957184d6),
the [Audit APIs](https://auditservice.docs.apiary.io/#),
providing both synchronous and asynchronous Clients.

---

Head over to the [Quick Start](quickstart.md) to get started with the basics.

If you find any issues or feel that this SDK is not adequately covering your use case,
please [open an issue](https://github.com/VinzenzKlass/anaplan-sdk/issues/new).
